.. _spkg_h11:

h11: A pure-Python, bring-your-own-I/O implementation of HTTP/1.1
=================================================================

Description
-----------

A pure-Python, bring-your-own-I/O implementation of HTTP/1.1

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/h11/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    0.16.0

version_requirements.txt::

    h11

Equivalent System Packages
--------------------------

(none known)
